# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorByCategoryChild(Model):
    """GHGFactorByCategoryChild.

    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param factor_id: The Factor Identifier
    :type factor_id: int
    :param factor_info: The Factor Info
    :type factor_info: str
    :param factor_description: The Factor Description
    :type factor_description: str
    """

    _attribute_map = {
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'factor_info': {'key': 'factorInfo', 'type': 'str'},
        'factor_description': {'key': 'factorDescription', 'type': 'str'},
    }

    def __init__(self, *, commodity=None, factor_id: int=None, factor_info: str=None, factor_description: str=None, **kwargs) -> None:
        super(GHGFactorByCategoryChild, self).__init__(**kwargs)
        self.commodity = commodity
        self.factor_id = factor_id
        self.factor_info = factor_info
        self.factor_description = factor_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteDetailsResponse(Model):
    """RouteDetailsResponse.

    :param meters: The meters assigned to this route
    :type meters:
     list[~energycap.sdk.models.MeterChildIncludePlaceAndSerialNumber]
    :param number_of_meters: The number of meters assigned to this route
    :type number_of_meters: int
    :param route_id: The route identifier
    :type route_id: int
    :param route_info: The route info
    :type route_info: str
    :param route_code: The route code
    :type route_code: str
    """

    _attribute_map = {
        'meters': {'key': 'meters', 'type': '[MeterChildIncludePlaceAndSerialNumber]'},
        'number_of_meters': {'key': 'numberOfMeters', 'type': 'int'},
        'route_id': {'key': 'routeId', 'type': 'int'},
        'route_info': {'key': 'routeInfo', 'type': 'str'},
        'route_code': {'key': 'routeCode', 'type': 'str'},
    }

    def __init__(self, *, meters=None, number_of_meters: int=None, route_id: int=None, route_info: str=None, route_code: str=None, **kwargs) -> None:
        super(RouteDetailsResponse, self).__init__(**kwargs)
        self.meters = meters
        self.number_of_meters = number_of_meters
        self.route_id = route_id
        self.route_info = route_info
        self.route_code = route_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestNormalizedMonthlyResponseCommodityData(Model):
    """PlaceDigestNormalizedMonthlyResponseCommodityData.

    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param common_demand_unit:
    :type common_demand_unit: ~energycap.sdk.models.UnitChild
    :param results: An array of commodity monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestNormalizedMonthlyResponseCommodityResults]
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestNormalizedCommodityTargetComparisonMonthly
    """

    _attribute_map = {
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'common_demand_unit': {'key': 'commonDemandUnit', 'type': 'UnitChild'},
        'results': {'key': 'results', 'type': '[PlaceDigestNormalizedMonthlyResponseCommodityResults]'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestNormalizedCommodityTargetComparisonMonthly'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestNormalizedMonthlyResponseCommodityData, self).__init__(**kwargs)
        self.commodity_code = kwargs.get('commodity_code', None)
        self.commodity_info = kwargs.get('commodity_info', None)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.common_use_unit = kwargs.get('common_use_unit', None)
        self.common_demand_unit = kwargs.get('common_demand_unit', None)
        self.results = kwargs.get('results', None)
        self.target_comparison = kwargs.get('target_comparison', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WatticsSite(Model):
    """WatticsSite.

    :param wattics_site_id: The identifier for a Wattics site
    :type wattics_site_id: int
    """

    _attribute_map = {
        'wattics_site_id': {'key': 'watticsSiteId', 'type': 'int'},
    }

    def __init__(self, *, wattics_site_id: int=None, **kwargs) -> None:
        super(WatticsSite, self).__init__(**kwargs)
        self.wattics_site_id = wattics_site_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdate(Model):
    """Bill header values to update.

    All required parameters must be populated in order to send to Azure.

    :param begin_date: Required.
    :type begin_date: ~energycap.sdk.models.BillHeaderUpdateBeginDateChild
    :param end_date: Required.
    :type end_date: ~energycap.sdk.models.BillHeaderUpdateEndDateChild
    :param due_date: Required.
    :type due_date: ~energycap.sdk.models.BillHeaderUpdateDueDateChild
    :param statement_date: Required.
    :type statement_date:
     ~energycap.sdk.models.BillHeaderUpdateStatementDateChild
    :param control_code: Required.
    :type control_code: ~energycap.sdk.models.BillHeaderUpdateControlCodeChild
    :param invoice_number: Required.
    :type invoice_number:
     ~energycap.sdk.models.BillHeaderUpdateInvoiceNumberChild
    :param account_period: Required.
    :type account_period:
     ~energycap.sdk.models.BillHeaderUpdateAccountPeriodChild
    :param billing_period: Required.
    :type billing_period:
     ~energycap.sdk.models.BillHeaderUpdateBillingPeriodChild
    :param estimated: Required.
    :type estimated: ~energycap.sdk.models.BillHeaderUpdateEstimatedChild
    """

    _validation = {
        'begin_date': {'required': True},
        'end_date': {'required': True},
        'due_date': {'required': True},
        'statement_date': {'required': True},
        'control_code': {'required': True},
        'invoice_number': {'required': True},
        'account_period': {'required': True},
        'billing_period': {'required': True},
        'estimated': {'required': True},
    }

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'BillHeaderUpdateBeginDateChild'},
        'end_date': {'key': 'endDate', 'type': 'BillHeaderUpdateEndDateChild'},
        'due_date': {'key': 'dueDate', 'type': 'BillHeaderUpdateDueDateChild'},
        'statement_date': {'key': 'statementDate', 'type': 'BillHeaderUpdateStatementDateChild'},
        'control_code': {'key': 'controlCode', 'type': 'BillHeaderUpdateControlCodeChild'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'BillHeaderUpdateInvoiceNumberChild'},
        'account_period': {'key': 'accountPeriod', 'type': 'BillHeaderUpdateAccountPeriodChild'},
        'billing_period': {'key': 'billingPeriod', 'type': 'BillHeaderUpdateBillingPeriodChild'},
        'estimated': {'key': 'estimated', 'type': 'BillHeaderUpdateEstimatedChild'},
    }

    def __init__(self, **kwargs):
        super(BillHeaderUpdate, self).__init__(**kwargs)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.due_date = kwargs.get('due_date', None)
        self.statement_date = kwargs.get('statement_date', None)
        self.control_code = kwargs.get('control_code', None)
        self.invoice_number = kwargs.get('invoice_number', None)
        self.account_period = kwargs.get('account_period', None)
        self.billing_period = kwargs.get('billing_period', None)
        self.estimated = kwargs.get('estimated', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodComparison(Model):
    """General purpose period comparison DTO.

    :param current_period: The date for the current period of data
    :type current_period: int
    :param previous_period: The date for the previous period of data
    :type previous_period: int
    :param current_value:
    :type current_value: ~energycap.sdk.models.ValueWithUnit
    :param previous_value:
    :type previous_value: ~energycap.sdk.models.ValueWithUnit
    """

    _attribute_map = {
        'current_period': {'key': 'currentPeriod', 'type': 'int'},
        'previous_period': {'key': 'previousPeriod', 'type': 'int'},
        'current_value': {'key': 'currentValue', 'type': 'ValueWithUnit'},
        'previous_value': {'key': 'previousValue', 'type': 'ValueWithUnit'},
    }

    def __init__(self, **kwargs):
        super(PeriodComparison, self).__init__(**kwargs)
        self.current_period = kwargs.get('current_period', None)
        self.previous_period = kwargs.get('previous_period', None)
        self.current_value = kwargs.get('current_value', None)
        self.previous_value = kwargs.get('previous_value', None)
